﻿using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using System;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

public partial class _Default : System.Web.UI.Page
{
	protected void Page_Load(object sender, EventArgs e)
	{
		//  Create and add all the stacked column series
		NumericSeries[] stackColumnSeries = this.GetStackColumnSeries();
		UltraChart1.CompositeChart.Series.AddRange(stackColumnSeries);

		//  Create and add the line series
		XYSeries lineSeries = this.GetLineSeries();
		UltraChart1.CompositeChart.Series.Add(lineSeries);

		//  Add and set up column layer. This layer will render column chart
		ChartLayerAppearance stackColumnLayer = UltraChart1.CompositeChart.ChartLayers.FromKey("stackColumnLayer");
		stackColumnLayer.SeriesList = "Week1|Week2|Week3|Week4|Week5";
		stackColumnLayer.SwapRowsAndColumns = true;
		stackColumnLayer.Series.AddRange(stackColumnSeries);

		//  Add and set up line layer. This layer will render line chart
		ChartLayerAppearance lineLayer = UltraChart1.CompositeChart.ChartLayers.FromKey("lineLayer");
		lineLayer.Series.Add(lineSeries);
	}

	private NumericSeries[] GetStackColumnSeries()
	{
		List<NumericSeries> series = new List<NumericSeries>();
		DataTable stackColumnData = GetData();

		NumericSeries seriesWeek1 = new NumericSeries();
		seriesWeek1.Key = "Week1";
		seriesWeek1.Data.DataSource = stackColumnData;
		seriesWeek1.Data.LabelColumn = "Symbol";
		seriesWeek1.Data.ValueColumn = "Week1";
		series.Add(seriesWeek1);

		NumericSeries seriesWeek2 = new NumericSeries();
		seriesWeek2.Key = "Week2";
		seriesWeek2.Data.DataSource = stackColumnData;
		seriesWeek2.Data.LabelColumn = "Symbol";
		seriesWeek2.Data.ValueColumn = "Week2";
		series.Add(seriesWeek2);

		NumericSeries seriesWeek3 = new NumericSeries();
		seriesWeek3.Key = "Week3";
		seriesWeek3.Data.DataSource = stackColumnData;
		seriesWeek3.Data.LabelColumn = "Symbol";
		seriesWeek3.Data.ValueColumn = "Week3";
		series.Add(seriesWeek3);

		NumericSeries seriesWeek4 = new NumericSeries();
		seriesWeek4.Key = "Week4";
		seriesWeek4.Data.DataSource = stackColumnData;
		seriesWeek4.Data.LabelColumn = "Symbol";
		seriesWeek4.Data.ValueColumn = "Week4";
		series.Add(seriesWeek4);

		NumericSeries seriesWeek5 = new NumericSeries();
		seriesWeek5.Key = "Week5";
		seriesWeek5.Data.DataSource = stackColumnData;
		seriesWeek5.Data.LabelColumn = "Symbol";
		seriesWeek5.Data.ValueColumn = "Week5";
		series.Add(seriesWeek5);

		return series.ToArray();
	}

	private XYSeries GetLineSeries()
	{
		XYSeries series = new XYSeries();
		series.Label = "Line";

		series.Points.Add(new XYDataPoint(1, 20, "ActiveX", false));
		series.Points.Add(new XYDataPoint(3, 80, "Java", false));
		series.Points.Add(new XYDataPoint(5, 60, ".NET", false));

		series.PEs.Clear();
		series.PEs.Add(new PaintElement(Color.Red));

		return series;
	}

	#region TestData
	public DataTable GetData()
	{
		DataTable t = new DataTable();

		t.Columns.Add("Symbol", typeof(string));
		t.Columns.Add("Week1", typeof(double));
		t.Columns.Add("Week2", typeof(double));
		t.Columns.Add("Week3", typeof(double));
		t.Columns.Add("Week4", typeof(double));
		t.Columns.Add("Week5", typeof(double));

		t.Rows.Add(new object[] { "ActiveX", 25, 15, 100, 120, 60 });
		t.Rows.Add(new object[] { "Java", 85, 200, 45, 75, 113 });
		t.Rows.Add(new object[] { ".NET", 65, 95, 110, 99, 50 });

		return t;
	}
	#endregion
}